@@ -11,7 +11,7 @@ from pulpcore.plugin.serializers import (
     AsyncOperationResponseSerializer,
     RepositorySyncURLSerializer,
 )
-from pulpcore.plugin.tasking import enqueue_with_reservation
+from pulpcore.plugin.tasking import dispatch
 
 from pulp_python.app import models as python_models
 from pulp_python.app import serializers as python_serializers
@@ -49,12 +49,12 @@ class PythonRepositoryViewSet(core_viewsets.RepositoryViewSet, ModifyRepositoryA
         remote = serializer.validated_data.get('remote', repository.remote)
         mirror = serializer.validated_data.get('mirror')
 
-        result = enqueue_with_reservation(
+        result = dispatch(
             tasks.sync,
             [repository, remote],
             kwargs={
-                'remote_pk': remote.pk,
-                'repository_pk': repository.pk,
+                'remote_pk': str(remote.pk),
+                'repository_pk': str(repository.pk),
                 'mirror': mirror
             }
         )
@@ -69,7 +69,7 @@ class PythonRepositoryVersionViewSet(core_viewsets.RepositoryVersionViewSet):
     parent_viewset = PythonRepositoryViewSet
 
 
-class PythonDistributionViewSet(core_viewsets.BaseDistributionViewSet):
+class PythonDistributionViewSet(core_viewsets.DistributionViewSet):
     """
     <!-- User-facing documentation, rendered as html-->
     Pulp Python Distributions are used to distribute
@@ -160,12 +160,22 @@ class PythonRemoteViewSet(core_viewsets.RemoteViewSet):
         enabled = bander_config.get("plugins", "enabled")
         enabled_all = "all" in enabled
         data["prereleases"] = not (enabled_all or "prerelease_release" in enabled)
-        if bander_config.has_option("allowlist", "packages") and \
-                (enabled_all or "allowlist_project" in enabled):
-            data["includes"] = bander_config.get("allowlist", "packages").split()
-        if bander_config.has_option("blocklist", "packages") and \
-                (enabled_all or "blocklist_project" in enabled):
-            data["excludes"] = bander_config.get("blocklist", "packages").split()
+        # TODO refactor to use a translation object
+        plugin_filters = {  # plugin : (section_name, bander_option, pulp_option)
+            "allowlist_project": ("allowlist", "packages", "includes"),
+            "blocklist_project": ("blocklist", "packages", "excludes"),
+            "regex_release_file_metadata": (
+                "regex_release_file_metadata",
+                "any:release_file.packagetype",
+                "package_types",
+            ),
+            "latest_release": ("latest_release", "keep", "keep_latest_packages"),
+            "exclude_platform": ("blocklist", "platforms", "exclude_platforms"),
+        }
+        for plugin, options in plugin_filters.items():
+            if (enabled_all or plugin in enabled) and \
+                    bander_config.has_option(options[0], options[1]):
+                data[options[2]] = bander_config.get(options[0], options[1]).split()
         remote = python_serializers.PythonRemoteSerializer(data=data, context={"request": request})
         remote.is_valid(raise_exception=True)
         remote.save()
@@ -203,11 +213,11 @@ class PythonPublicationViewSet(core_viewsets.PublicationViewSet):
             repository = serializer.validated_data.get('repository')
             repository_version = RepositoryVersion.latest(repository)
 
-        result = enqueue_with_reservation(
+        result = dispatch(
             tasks.publish,
             [repository_version.repository],
             kwargs={
-                'repository_version_pk': repository_version.pk
+                'repository_version_pk': str(repository_version.pk)
             }
         )
         return core_viewsets.OperationPostponedResponse(result, request)
